@@ -13,11 +13,10 @@ import re
 import smtplib
 import threading
 
-import html2text
-
 from odoo import api, fields, models, tools, _
 from odoo.exceptions import except_orm, UserError
-from odoo.tools import ustr, pycompat
+from odoo.tools import ustr, pycompat, encapsulate_email, email_domain_extract
+
 
 _logger = logging.getLogger(__name__)
 _test_logger = logging.getLogger('odoo.tests')
@@ -353,8 +352,14 @@ class IrMailServer(models.Model):
         msg['Message-Id'] = encode_header(message_id)
         if references:
             msg['references'] = encode_header(references)
+
+        email_from = encode_rfc2822_address_header(email_from)
+        email_from, return_path = self._get_email_from(email_from)
+        msg['From'] = email_from
+        if return_path:
+            headers.setdefault('Return-Path', return_path)
+
         msg['Subject'] = encode_header(subject)
-        msg['From'] = encode_rfc2822_address_header(email_from)
         del msg['Reply-To']
         if reply_to:
             msg['Reply-To'] = encode_rfc2822_address_header(reply_to)
@@ -372,7 +377,7 @@ class IrMailServer(models.Model):
 
         if subtype == 'html' and not body_alternative:
             # Always provide alternative text body ourselves if possible.
-            text = html2text.html2text(email_body)
+            text = tools.html2plaintext(email_body)
             alternative_part = MIMEMultipart(_subtype="alternative")
             alternative_part.attach(MIMEText(text, _charset='utf-8', _subtype='plain'))
             alternative_part.attach(email_text_part)
@@ -407,6 +412,35 @@ class IrMailServer(models.Model):
                 msg.attach(part)
         return msg
 
+    def _get_email_from(self, email_from):
+        """Logic which determines which email to use when sending the email.
+
+        - If the system parameter `mail.force.smtp.from` is set we encapsulate all
+          outgoing email from
+        - If the previous system parameter is not set and if both `mail.dynamic.smtp.from`
+          and `mail.catchall.domain` are set, we encapsulate the FROM only if the domain
+          of the email is not the same as the domain of the catchall parameter
+        - Otherwise we do not encapsulate the email and given email_from is used as is
+
+        :param email_from: The initial FROM headers
+        :return: The FROM to used in the headers and optionally the Return-Path
+        """
+        force_smtp_from = self.env['ir.config_parameter'].sudo().get_param('mail.force.smtp.from')
+        dynamic_smtp_from = self.env['ir.config_parameter'].sudo().get_param('mail.dynamic.smtp.from')
+        catchall_domain = self.env['ir.config_parameter'].sudo().get_param('mail.catchall.domain')
+
+        if force_smtp_from:
+            rfc2822_force_smtp_from = extract_rfc2822_addresses(force_smtp_from)
+            rfc2822_force_smtp_from = rfc2822_force_smtp_from[0] if rfc2822_force_smtp_from else None
+            return encapsulate_email(email_from, force_smtp_from), rfc2822_force_smtp_from
+
+        elif dynamic_smtp_from and catchall_domain and email_domain_extract(email_from) != catchall_domain:
+            rfc2822_dynamic_smtp_from = extract_rfc2822_addresses(dynamic_smtp_from)
+            rfc2822_dynamic_smtp_from = rfc2822_dynamic_smtp_from[0] if rfc2822_dynamic_smtp_from else None
+            return encapsulate_email(email_from, dynamic_smtp_from), rfc2822_dynamic_smtp_from
+
+        return email_from, None
+
     @api.model
     def _get_default_bounce_address(self):
         '''Compute the default bounce address.
