@@ -669,6 +669,8 @@ class Users(models.Model):
         try:
             self = api.Environment(cr, uid, {})[cls._name]
             with self._assert_can_auth():
+                if not self.env.user.active:
+                    raise AccessDenied()
                 self._check_credentials(passwd)
                 cls.__uid_cache[db][uid] = passwd
         finally:
@@ -876,7 +878,7 @@ class Users(models.Model):
                     "and *might* be a proxy. If your Odoo is behind a proxy, "
                     "it may be mis-configured. Check that you are running "
                     "Odoo in Proxy Mode and that the proxy is properly configured, see "
-                    "https://www.odoo.com/documentation/13.0/setup/deploy.html#https for details.",
+                    "https://www.odoo.com/documentation/13.0/administration/deployment/deploy.html#https for details.",
                     source
                 )
             raise AccessDenied(_("Too many login failures, please wait a bit before trying again."))
