@@ -3,6 +3,8 @@
 
 from collections import defaultdict
 
+import psycopg2
+
 from odoo.exceptions import AccessError, MissingError
 from odoo.tests.common import TransactionCase
 from odoo.tools import mute_logger
@@ -136,6 +138,7 @@ class TestORM(TransactionCase):
         self.assertEqual(len(found), 1)
         self.assertTrue(field in list(found[0]) for field in ['id', 'name', 'display_name', 'email'])
 
+    @mute_logger('odoo.sql_db')
     def test_exists(self):
         partner = self.env['res.partner']
 
@@ -144,10 +147,19 @@ class TestORM(TransactionCase):
         self.assertTrue(recs)
         self.assertEqual(recs.exists(), recs)
 
+        # check that new records exist by convention
+        recs = partner.new({})
+        self.assertTrue(recs.exists())
+
         # check that there is no record with id 0
         recs = partner.browse([0])
         self.assertFalse(recs.exists())
 
+        # check that there is no record with string id
+        recs = partner.browse('xxx')
+        with self.assertRaises(psycopg2.DataError):
+            recs.exists()
+
     def test_groupby_date(self):
         partners_data = dict(
             A='2012-11-19',
