@@ -205,3 +205,53 @@ class base_automation_test(common.TransactionCase):
         self.assertEqual(lead.name, 'XX', "No update should have happened.")
         lead.partner_id = partner1
         self.assertEqual(lead.name, 'XXX', "One update should have happened.")
+
+@common.tagged('post_install','-at_install')
+class TestCompute(common.TransactionCase):
+    def test_inversion(self):
+        """ If a stored field B depends on A, an update to the trigger for A
+        should trigger the recomputaton of A, then B.
+
+        However if a search() is performed during the computation of A
+        ??? and _order is affected ??? a flush will be triggered, forcing the
+        computation of B, based on the previous A.
+
+        This happens if a rule has has a non-empty filter_pre_domain, even if
+        it's an empty list (``'[]'`` as opposed to ``False``).
+        """
+        company1 = self.env['res.partner'].create({
+            'name': "Gorofy",
+            'is_company': True,
+        })
+        company2 = self.env['res.partner'].create({
+            'name': "Awiclo",
+            'is_company': True
+        })
+        r = self.env['res.partner'].create({
+            'name': 'Bob',
+            'is_company': False,
+            'parent_id': company1.id
+        })
+        self.assertEqual(r.display_name, 'Gorofy, Bob')
+        r.parent_id = company2
+        self.assertEqual(r.display_name, 'Awiclo, Bob')
+
+        self.env['base.automation'].create({
+            'name': "test rule",
+            'filter_pre_domain': False,
+            'trigger': 'on_create_or_write',
+            'state': 'code', # no-op action
+            'model_id': self.env.ref('base.model_res_partner').id,
+        })
+        r.parent_id = company1
+        self.assertEqual(r.display_name, 'Gorofy, Bob')
+
+        self.env['base.automation'].create({
+            'name': "test rule",
+            'filter_pre_domain': '[]',
+            'trigger': 'on_create_or_write',
+            'state': 'code', # no-op action
+            'model_id': self.env.ref('base.model_res_partner').id,
+        })
+        r.parent_id = company2
+        self.assertEqual(r.display_name, 'Awiclo, Bob')
