@@ -452,3 +452,31 @@ class TestCalendar(TransactionCase):
         # since the detach actually create an event in the backend
         # we check that no mail notifications are sent to the attendees
         _test_one_mail_per_attendee(self, m, partners)
+
+    def test_event_creation_mail_with_different_owner(self):
+        admin = self.env.ref('base.user_admin')
+        demo = self.env.ref('base.user_demo')
+        now = fields.Datetime.now()
+        partners = [
+           self.env['res.partner'].create({'name': 'testuser0', 'email': u'bob@example.com'}),
+           self.env['res.partner'].create({'name': 'testuser1', 'email': u'alice@example.com'}),
+           ]
+        partner_ids = [(6, False, [p.id for p in partners]), ]
+
+        m = self.CalendarEvent.with_user(admin).create({
+            'name': "mailTest1",
+            'partner_ids': partner_ids,
+            'allday': False,
+            'duration': 0.5,
+            'user_id': demo.id,
+            'start': fields.Datetime.to_string(now + timedelta(days=10)),
+            'stop': fields.Datetime.to_string(now + timedelta(days=15)),
+            })
+
+        for partner in partners:
+            mail = self.env['mail.mail'].search([
+                ('recipient_ids', 'in', partner.id),
+                ('subject', 'like', m.name),
+                ])
+            self.assertEqual(len(mail), 1)
+            self.assertEqual(mail.author_id.id, demo.partner_id.id)
