@@ -57,5 +57,6 @@
     'css': ['static/src/css/crm.css'],
     'installable': True,
     'application': True,
-    'auto_install': False
+    'auto_install': False,
+    'license': 'LGPL-3',
 }
