@@ -117,7 +117,7 @@ class Team(models.Model):
     as a member of one of the Sales Team.
 </p>""")
             if user_team_id:
-                action['help'] += "<p>As you don't belong to any Sales Team, Odoo opens the first one by default.</p>"
+                action['help'] += _("<p>As you don't belong to any Sales Team, Odoo opens the first one by default.</p>")
 
         action_context = safe_eval(action['context'], {'uid': self.env.uid})
         if user_team_id:
