@@ -190,7 +190,21 @@ class EventMailRegistration(models.Model):
     def execute(self):
         for mail in self:
             if mail.registration_id.state in ['open', 'done'] and not mail.mail_sent and mail.scheduler_id.notification_type == 'mail':
-                mail.scheduler_id.template_id.send_mail(mail.registration_id.id)
+                organizer = mail.scheduler_id.event_id.organizer_id
+                company = self.env.company
+                author = self.env.ref('base.user_root')
+                if organizer.email:
+                    author = organizer
+                elif company.email:
+                    author = company.partner_id
+                elif self.env.user.email:
+                    author = self.env.user
+                
+                email_values = {
+                    'email_from': author.email_formatted,
+                    'author_id': author.id,
+                }
+                mail.scheduler_id.template_id.send_mail(mail.registration_id.id, email_values=email_values)
                 mail.write({'mail_sent': True})
 
     @api.depends('registration_id', 'scheduler_id.interval_unit', 'scheduler_id.interval_type')
