@@ -75,7 +75,7 @@ class GoogleDrive(models.Model):
         try:
             req = requests.post(
                 'https://spreadsheets.google.com/feeds/cells/%s/od6/private/full/batch?%s' % (spreadsheet_key, werkzeug.url_encode({'v': 3, 'access_token': access_token})),
-                data=request,
+                data=request.encode('utf-8'),
                 headers={'content-type': 'application/atom+xml', 'If-Match': '*'},
                 timeout=TIMEOUT,
             )
