@@ -2,7 +2,7 @@
 {
     'name': "Check Printing in Expenses",
     'summary': """Print amount in words on checks issued for expenses""",
-    'category': 'Accounting',
+    'category': 'Accounting/Expenses',
     'description': """
         Print amount in words on checks issued for expenses
     """,
@@ -12,4 +12,5 @@
     'data': [
         'views/payment.xml',
     ],
+    'license': 'LGPL-3',
 }
