@@ -30,5 +30,6 @@
         'data/account_tax_template_data.xml',
         'data/account_chart_template_data.xml',
     ],
-    'auto_install': True
+    'auto_install': True,
+    'license': 'LGPL-3',
 }
