@@ -14,7 +14,7 @@
     'category': 'Localization',
     'description': 'Colombian Accounting and Tax Preconfiguration',
     'author': 'David Arnold (XOE Solutions)',
-    'website': 'https://xoe.solutions',
+    'website': 'https://www.odoo.com/colombia',
     'depends': [
         'account',
     ],
@@ -27,4 +27,5 @@
         'data/account_chart_template_configure_data.xml',
         'views/res_partner.xml',
     ],
+    'license': 'LGPL-3',
 }
