@@ -5,15 +5,17 @@
     'name': 'Indian - Purchase Report(GST)',
     'version': '1.0',
     'description': """GST Purchase Report""",
-    'category': 'Accounting',
+    'category': 'Accounting/Accounting',
     'depends': [
         'l10n_in',
         'purchase',
     ],
     'data': [
         'views/report_purchase_order.xml',
+        'views/purchase_order_views.xml',
     ],
     'installable': True,
     'application': False,
     'auto_install': True,
+    'license': 'LGPL-3',
 }
