@@ -163,7 +163,7 @@ class AccountMove(models.Model):
                 'name': report_name,
                 'res_id': invoice.id,
                 'res_model': invoice._name,
-                'datas': base64.encodestring(data),
+                'datas': base64.encodebytes(data),
                 'description': description,
                 'type': 'binary',
                 })
@@ -172,7 +172,7 @@ class AccountMove(models.Model):
                 body=(_("E-Invoice is generated on %s by %s") % (fields.Datetime.now(), self.env.user.display_name))
             )
 
-    def _export_as_xml(self):
+    def _prepare_fatturapa_export_values(self):
         ''' Create the xml file content.
         :return: The XML content as str.
         '''
@@ -241,6 +241,13 @@ class AccountMove(models.Model):
         pdf = base64.b64encode(pdf)
         pdf_name = re.sub(r'\W+', '', self.name) + '.pdf'
 
+        # tax map for 0% taxes which have no tax_line_id
+        tax_map = dict()
+        for line in self.line_ids:
+            for tax in line.tax_ids:
+                if tax.amount == 0.0:
+                    tax_map[tax] = tax_map.get(tax, 0.0) + line.price_subtotal
+
         # Create file content.
         template_values = {
             'record': self,
@@ -258,7 +265,12 @@ class AccountMove(models.Model):
             'document_type': document_type,
             'pdf': pdf,
             'pdf_name': pdf_name,
+            'tax_map': tax_map,
         }
+        return template_values
+
+    def _export_as_xml(self):
+        template_values = self._prepare_fatturapa_export_values()
         content = self.env.ref('l10n_it_edi.account_invoice_it_FatturaPA_export').render(template_values)
         return content
 
