@@ -14,6 +14,7 @@ from werkzeug import urls, utils
 from odoo import models, fields, api, _
 
 
+URL_MAX_SIZE = 10 * 1024 * 1024
 URL_REGEX = r'(\bhref=[\'"](?!mailto:|tel:|sms:)([^\'"]+)[\'"])'
 TEXT_URL_REGEX = r'https?://[a-zA-Z0-9@:%._\+~#=/-]+(?:\?\S+)?'
 
@@ -82,8 +83,11 @@ class LinkTracker(models.Model):
         for tracker in self:
             parsed = urls.url_parse(tracker.url)
             utms = {}
-            for key, field, cook in self.env['utm.mixin'].tracking_fields():
-                attr = getattr(tracker, field).name
+            for key, field_name, cook in self.env['utm.mixin'].tracking_fields():
+                field = self._fields[field_name]
+                attr = getattr(tracker, field_name)
+                if field.type == 'many2one':
+                    attr = attr.name
                 if attr:
                     utms[key] = attr
             utms.update(parsed.decode_query())
@@ -93,7 +97,15 @@ class LinkTracker(models.Model):
     @api.depends('url')
     def _get_title_from_url(self, url):
         try:
-            page = requests.get(url, timeout=5)
+            head = requests.head(url, timeout=5)
+            if (
+                    int(head.headers.get('Content-Length', 0)) > URL_MAX_SIZE
+                    or
+                    'text/html' not in head.headers.get('Content-Type', 'text/html')
+            ):
+                return url
+            # HTML parser can work with a part of page, so ask server to limit downloading to 50 KB
+            page = requests.get(url, timeout=5, headers={"range": "bytes=0-50000"})
             p = html.fromstring(page.text.encode('utf-8'), parser=html.HTMLParser(encoding='utf-8'))
             title = p.find('.//title').text
         except:
@@ -166,6 +178,8 @@ class LinkTracker(models.Model):
         return html
 
     def _convert_links_text(self, body, vals, blacklist=None):
+        if not body:
+            return body
         shortened_schema = self.env['ir.config_parameter'].sudo().get_param('web.base.url') + '/r/'
         unsubscribe_schema = self.env['ir.config_parameter'].sudo().get_param('web.base.url') + '/sms/'
         for original_url in re.findall(TEXT_URL_REGEX, body):
@@ -227,6 +241,7 @@ class LinkTracker(models.Model):
 class LinkTrackerCode(models.Model):
     _name = "link.tracker.code"
     _description = "Link Tracker Code"
+    _rec_name = 'code'
 
     code = fields.Char(string='Short URL Code', required=True, store=True)
     link_id = fields.Many2one('link.tracker', 'Link', required=True, ondelete='cascade')
