@@ -270,7 +270,7 @@ class MrpWorkcenterProductivity(models.Model):
     @api.depends('date_end', 'date_start')
     def _compute_duration(self):
         for blocktime in self:
-            if blocktime.date_end:
+            if blocktime.date_start and blocktime.date_end:
                 d1 = fields.Datetime.from_string(blocktime.date_start)
                 d2 = fields.Datetime.from_string(blocktime.date_end)
                 diff = d2 - d1
