@@ -49,40 +49,6 @@ class ProductTemplate(models.Model):
         }
         return action
 
-    def _compute_quantities(self):
-        """ When the product template is a kit, this override computes the fields :
-         - 'virtual_available'
-         - 'qty_available'
-         - 'incoming_qty'
-         - 'outgoing_qty'
-         - 'free_qty'
-        """
-        product_without_bom = self.browse([])
-        for product_template in self:
-            if not self.env['mrp.bom']._bom_find(product_tmpl=product_template, bom_type='phantom'):
-                product_without_bom |= product_template
-                continue
-            virtual_available = 0
-            qty_available = 0
-            incoming_qty = 0
-            outgoing_qty = 0
-            free_qty = 0
-            for product in product_template.product_variant_ids:
-                if self.env['mrp.bom']._bom_find(product=product, bom_type='phantom'):
-                    qty_available += product.qty_available
-                    virtual_available += product.virtual_available
-                    incoming_qty += product.incoming_qty
-                    outgoing_qty += product.outgoing_qty
-                    free_qty += product.free_qty
-            product_template.qty_available = qty_available
-            product_template.virtual_available = virtual_available
-            product_template.incoming_qty = incoming_qty
-            product_template.outgoing_qty = outgoing_qty
-            product_template.free_qty = free_qty
-            
-        super(ProductTemplate, product_without_bom)._compute_quantities()
-
-
 class ProductProduct(models.Model):
     _inherit = "product.product"
 
@@ -132,27 +98,22 @@ class ProductProduct(models.Model):
                 continue
             product.mrp_product_qty = float_round(mapped_data.get(product.id, 0), precision_rounding=product.uom_id.rounding)
 
-    def _compute_quantities(self):
+    def _compute_quantities_dict(self, lot_id, owner_id, package_id, from_date=False, to_date=False):
         """ When the product is a kit, this override computes the fields :
          - 'virtual_available'
          - 'qty_available'
          - 'incoming_qty'
          - 'outgoing_qty'
          - 'free_qty'
+
+        This override is used to get the correct quantities of products
+        with 'phantom' as BoM type.
         """
-        self.virtual_available = 0
-        self.qty_available = 0
-        self.incoming_qty = 0
-        self.outgoing_qty = 0
-        self.free_qty = 0
-        bom_kits = {
-            product: bom
-            for product in self
-            for bom in (self.env['mrp.bom']._bom_find(product=product, bom_type='phantom'),)
-            if bom
-        }
+        bom_kits = self.env['mrp.bom']._get_product2bom(self, bom_type='phantom')
         kits = self.filtered(lambda p: bom_kits.get(p))
-        super(ProductProduct, self.filtered(lambda p: p not in bom_kits))._compute_quantities()
+        res = super(ProductProduct, self - kits)._compute_quantities_dict(lot_id, owner_id, package_id, from_date=from_date, to_date=to_date)
+        qties = self.env.context.get("mrp_compute_quantities", {})
+        qties.update(res)
         for product in bom_kits:
             boms, bom_sub_lines = bom_kits[product].explode(product, 1)
             ratios_virtual_available = []
@@ -161,7 +122,7 @@ class ProductProduct(models.Model):
             ratios_outgoing_qty = []
             ratios_free_qty = []
             for bom_line, bom_line_data in bom_sub_lines:
-                component = bom_line.product_id
+                component = bom_line.product_id.with_context(mrp_compute_quantities=qties)
                 if component.type != 'product' or float_is_zero(bom_line_data['qty'], precision_rounding=bom_line.product_uom_id.rounding):
                     # As BoMs allow components with 0 qty, a.k.a. optionnal components, we simply skip those
                     # to avoid a division by zero. The same logic is applied to non-storable products as those
@@ -171,17 +132,36 @@ class ProductProduct(models.Model):
                 qty_per_kit = bom_line.product_uom_id._compute_quantity(uom_qty_per_kit, bom_line.product_id.uom_id, raise_if_failure=False)
                 if not qty_per_kit:
                     continue
-                ratios_virtual_available.append(component.virtual_available / qty_per_kit)
-                ratios_qty_available.append(component.qty_available / qty_per_kit)
-                ratios_incoming_qty.append(component.incoming_qty / qty_per_kit)
-                ratios_outgoing_qty.append(component.outgoing_qty / qty_per_kit)
-                ratios_free_qty.append(component.free_qty / qty_per_kit)
+                component_res = qties.get(component.id, {
+                    "virtual_available": component.virtual_available,
+                    "qty_available": component.qty_available,
+                    "incoming_qty": component.incoming_qty,
+                    "outgoing_qty": component.outgoing_qty,
+                    "free_qty": component.free_qty,
+                })
+                ratios_virtual_available.append(component_res["virtual_available"] / qty_per_kit)
+                ratios_qty_available.append(component_res["qty_available"] / qty_per_kit)
+                ratios_incoming_qty.append(component_res["incoming_qty"] / qty_per_kit)
+                ratios_outgoing_qty.append(component_res["outgoing_qty"] / qty_per_kit)
+                ratios_free_qty.append(component_res["free_qty"] / qty_per_kit)
             if bom_sub_lines and ratios_virtual_available:  # Guard against all cnsumable bom: at least one ratio should be present.
-                product.virtual_available = min(ratios_virtual_available) // 1
-                product.qty_available = min(ratios_qty_available) // 1
-                product.incoming_qty = min(ratios_incoming_qty) // 1
-                product.outgoing_qty = min(ratios_outgoing_qty) // 1
-                product.free_qty = min(ratios_free_qty) // 1
+                res[product.id] = {
+                    'virtual_available': min(ratios_virtual_available) // 1,
+                    'qty_available': min(ratios_qty_available) // 1,
+                    'incoming_qty': min(ratios_incoming_qty) // 1,
+                    'outgoing_qty': min(ratios_outgoing_qty) // 1,
+                    'free_qty': min(ratios_free_qty) // 1,
+                }
+            else:
+                res[product.id] = {
+                    'virtual_available': 0,
+                    'qty_available': 0,
+                    'incoming_qty': 0,
+                    'outgoing_qty': 0,
+                    'free_qty': 0,
+                }
+
+        return res
 
     def action_view_bom(self):
         action = self.env.ref('mrp.product_open_bom').read()[0]
@@ -212,4 +192,5 @@ class ProductProduct(models.Model):
         res = super(ProductProduct, components).action_open_quants()
         if bom_kits:
             res['context']['single_product'] = False
+            res['context'].pop('default_product_tmpl_id', None)
         return res
