@@ -116,16 +116,16 @@ class StockRule(models.Model):
             'move_dest_ids': values.get('move_dest_ids') and [(4, x.id) for x in values['move_dest_ids']] or False,
             'user_id': False,
         }
+        # Use the procurement group created in _run_pull mrp override
+        # Preserve the origin from the original stock move, if available
         if location_id.get_warehouse().manufacture_steps == 'pbm_sam':
-            # Use the procurement group created in _run_pull mrp override
-            # Preserve the origin from the original stock move, if available
-            if len(values.get('move_dest_ids', [])) == 1 and values['move_dest_ids'][0].origin:
+            if values.get('move_dest_ids') and values.get('group_id') and values['move_dest_ids'][0].origin != values['group_id'].name:
                 origin = values['move_dest_ids'][0].origin
-            mo_values.update({
-                'name': values['group_id'].name,
-                'procurement_group_id': values['group_id'].id,
-                'origin': origin,
-            })
+                mo_values.update({
+                    'name': values['group_id'].name,
+                    'procurement_group_id': values['group_id'].id,
+                    'origin': origin,
+                })
         return mo_values
 
     def _get_date_planned(self, product_id, company_id, values):
