@@ -19,7 +19,7 @@ var MrpBomReport = stock_report_generic.extend({
         var self = this;
         var args = [
             this.given_context.active_id,
-            this.given_context.searchQty || 1,
+            this.given_context.searchQty || false,
             this.given_context.searchVariant,
         ];
         return this._rpc({
@@ -111,8 +111,8 @@ var MrpBomReport = stock_report_generic.extend({
         this.$buttonPrint.find('.o_mrp_bom_print').on('click', this._onClickPrint.bind(this));
         this.$buttonPrint.find('.o_mrp_bom_print_unfolded').on('click', this._onClickPrint.bind(this));
         this.$searchView = $(QWeb.render('mrp.report_bom_search', _.omit(this.data, 'lines')));
-        this.$searchView.find('.o_mrp_bom_report_qty').on('change', this._onChangeQty.bind(this));
-        this.$searchView.find('.o_mrp_bom_report_variants').on('change', this._onChangeVariants.bind(this));
+        this.$searchView.find('.o_mrp_bom_report_qty').on('change', this._onChangeQty.bind(this)).change();
+        this.$searchView.find('.o_mrp_bom_report_variants').on('change', this._onChangeVariants.bind(this)).change();
         this.$searchView.find('.o_mrp_bom_report_type').on('change', this._onChangeType.bind(this));
     },
     _onClickPrint: function (ev) {
