@@ -604,3 +604,34 @@ class TestUnbuild(TestMrpCommon):
         self.assertEqual(StockQuant._get_available_quantity(finshed_product, self.stock_location), 0, 'Table should not be available in stock')
         self.assertEqual(StockQuant._get_available_quantity(component1, self.stock_location), 1, 'Table head should be available in stock as the picking is transferred')
         self.assertEqual(StockQuant._get_available_quantity(component2, self.stock_location), 1, 'Table stand should be available in stock as the picking is transferred')
+
+    def test_unbuild_an_updated_mo(self):
+        """ Suppose the user has a MO with qty = 1. On Produce step, he increases the quantity to 3.
+        Then the user unbuilds one product"""
+        mo, bom, p_final, p1, p2 = self.generate_mo(qty_final=1, qty_base_1=1, qty_base_2=1)
+        self.env['stock.quant']._update_available_quantity(p1, self.stock_location, 3)
+        self.env['stock.quant']._update_available_quantity(p2, self.stock_location, 3)
+        mo.action_assign()
+
+        produce_form = Form(self.env['mrp.product.produce'].with_context({
+            'active_id': mo.id,
+            'active_ids': [mo.id],
+        }))
+        produce_form.qty_producing = 3
+        produce_wizard = produce_form.save()
+        produce_wizard.do_produce()
+
+        mo.button_mark_done()
+
+        ub_form = Form(self.env['mrp.unbuild'])
+        ub_form.mo_id = mo
+        self.assertEqual(ub_form.product_qty, 3)
+        ub_form.product_qty = 1
+        ub = ub_form.save()
+        ub.action_unbuild()
+
+        for p, qty in [(p1, 1), (p2, 1), (p_final, 2)]:
+            self.assertEqual(p.qty_available, qty, 'Inorrect qty for product %s' % p.name)
+            ub_sm = self.env['stock.move'].search([('product_id', '=', p.id), ('name', 'like', 'UB%')])
+            self.assertEqual(len(ub_sm), 1, 'Incorrect nb of SM for product %s' % p.name)
+            self.assertEqual(ub_sm.product_uom_qty, 1, 'Incorrect qty for prodcut %s' % p.name)
