@@ -148,6 +148,9 @@ class MrpProductProduce(models.TransientModel):
             quantity = wizard.qty_producing
             if float_compare(quantity, 0, precision_rounding=self.product_uom_id.rounding) <= 0:
                 raise UserError(_("The production order for '%s' has no quantity specified.") % self.product_id.display_name)
+            quantity = wizard.product_uom_id._compute_quantity(quantity, wizard.production_id.product_uom_id)
+            if float_compare(quantity, wizard.production_id.product_qty, precision_rounding=self.product_uom_id.rounding) > 0:
+                wizard.production_id.write({'product_qty': quantity})
         self._update_finished_move()
         self._update_moves()
         self.production_id.filtered(lambda mo: mo.state == 'confirmed').write({
@@ -178,3 +181,14 @@ class MrpProductProduceLine(models.TransientModel):
     def _get_production(self):
         product_produce_id = self.raw_product_produce_id or self.finished_product_produce_id
         return product_produce_id.production_id
+
+    @api.onchange('lot_id')
+    def _onchange_lot_id(self):
+        """ When the user is encoding a produce line for a tracked product, we apply some logic to
+        help him. This onchange will automatically switch `qty_done` to 1.0.
+        """
+        if self.product_id.tracking == 'serial':
+            if self.lot_id:
+                self.qty_done = 1
+            else:
+                self.qty_done = 0
