@@ -19,5 +19,6 @@ pads (by default, http://etherpad.com/).
     ],
     'demo': ['data/pad_demo.xml'],
     'web': True,
-    'qweb': ['static/src/xml/pad.xml']
+    'qweb': ['static/src/xml/pad.xml'],
+    'license': 'LGPL-3',
 }
