@@ -73,7 +73,7 @@ class AcquirerPaypal(models.Model):
         if not self.fees_active:
             return 0.0
         country = self.env['res.country'].browse(country_id)
-        if country and self.company_id.country_id.id == country.id:
+        if country and self.company_id.sudo().country_id.id == country.id:
             percentage = self.fees_dom_var
             fixed = self.fees_dom_fixed
         else:
