@@ -12,22 +12,16 @@ class PhoneValidationMixin(models.AbstractModel):
     def _phone_get_country(self):
         if 'country_id' in self and self.country_id:
             return self.country_id
-        return self.env.user.company_id.country_id
-
-    def _phone_get_always_international(self):
-        if 'company_id' in self and self.company_id:
-            return self.company_id.phone_international_format == 'prefix'
-        return self.env.user.company_id.phone_international_format == 'prefix'
+        return self.env.company.country_id
 
     def phone_format(self, number, country=None, company=None):
         country = country or self._phone_get_country()
         if not country:
             return number
-        always_international = company.phone_international_format == 'prefix' if company else self._phone_get_always_international()
         return phone_validation.phone_format(
             number,
             country.code if country else None,
             country.phone_code if country else None,
-            always_international=always_international,
+            force_format='INTERNATIONAL',
             raise_exception=False
         )
