@@ -1614,14 +1614,16 @@ var ClientListScreenWidget = ScreenWidget.extend({
             });
 
             contents.find('.image-uploader').on('change',function(event){
-                self.load_image_file(event.target.files[0],function(res){
-                    if (res) {
-                        contents.find('.client-picture img, .client-picture .fa').remove();
-                        contents.find('.client-picture').append("<img src='"+res+"'>");
-                        contents.find('.detail.picture').remove();
-                        self.uploaded_picture = res;
-                    }
-                });
+                if (event.target.files.length) {
+                    self.load_image_file(event.target.files[0],function(res){
+                        if (res) {
+                            contents.find('.client-picture img, .client-picture .fa').remove();
+                            contents.find('.client-picture').append("<img src='"+res+"'>");
+                            contents.find('.detail.picture').remove();
+                            self.uploaded_picture = res;
+                        }
+                    });
+                }
             });
         } else if (visibility === 'hide') {
             contents.empty();
@@ -1963,6 +1965,7 @@ var PaymentScreenWidget = ScreenWidget.extend({
         return numpad;
     },
     click_delete_paymentline: function(cid){
+        var self = this;
         var lines = this.pos.get_order().get_paymentlines();
         for ( var i = 0; i < lines.length; i++ ) {
             var line = lines[i];
@@ -1971,12 +1974,20 @@ var PaymentScreenWidget = ScreenWidget.extend({
                 // it is removed, the terminal should get a cancel
                 // request.
                 if (['waiting', 'waitingCard', 'timeout'].includes(lines[i].get_payment_status())) {
-                    line.payment_method.payment_terminal.send_payment_cancel(this.pos.get_order(), cid);
+                    line.set_payment_status('waitingCancel');
+                    this.render_paymentlines();
+                    line.payment_method.payment_terminal.send_payment_cancel(this.pos.get_order(), cid).then(function () {
+                        self.pos.get_order().remove_paymentline(line);
+                        self.reset_input();
+                        self.render_paymentlines();
+                    });
+                }
+                else if (lines[i].get_payment_status() !== 'waitingCancel') {
+                    this.pos.get_order().remove_paymentline(line);
+                    this.reset_input();
+                    this.render_paymentlines();
                 }
 
-                this.pos.get_order().remove_paymentline(line);
-                this.reset_input();
-                this.render_paymentlines();
                 return;
             }
         }
@@ -2347,7 +2358,7 @@ var PaymentScreenWidget = ScreenWidget.extend({
         var self = this;
         var order = this.pos.get_order();
 
-        if (order.is_paid_with_cash() && this.pos.config.iface_cashdrawer) { 
+        if ((order.is_paid_with_cash() || order.get_change()) && this.pos.config.iface_cashdrawer) { 
 
                 this.pos.proxy.printer.open_cashbox();
         }
@@ -2437,7 +2448,7 @@ var PaymentScreenWidget = ScreenWidget.extend({
         };
 
         var receipt = QWeb.render('OrderReceipt', data);
-        var printer = new Printer();
+        var printer = new Printer(null, this.pos);
 
         return new Promise(function (resolve, reject) {
             printer.htmlToImg(receipt).then(function(ticket) {
