@@ -404,6 +404,73 @@ class TestPointOfSaleFlow(TestPointOfSaleCommon):
         # I close the session to generate the journal entries
         self.pos_config.current_session_id.action_pos_session_closing_control()
 
+    def test_order_to_picking02(self):
+        """ This test is similar to test_order_to_picking except that this time, the product is tracked and its
+         location is a sublocation of the main warehouse
+        """
+        product = self.env['product.product'].create({
+            'name': 'SuperProduct',
+            'type': 'product',
+            'tracking': 'lot',
+            'available_in_pos': True,
+        })
+        wh_location = self.env['ir.model.data'].xmlid_to_object('stock.warehouse0').lot_stock_id
+        shelf1_location = self.env['stock.location'].create({
+            'name': 'shelf1',
+            'usage': 'internal',
+            'location_id': wh_location.id,
+        })
+        lot = self.env['stock.production.lot'].create({
+            'name': 'SuperLot',
+            'product_id': product.id,
+            'company_id': self.company.id,
+        })
+        qty = 2
+        self.env['stock.quant']._update_available_quantity(product, shelf1_location, qty, lot_id=lot)
+
+        self.pos_config.open_session_cb()
+
+        untax, atax = self.compute_tax(product, 1.15, 1)
+
+        for i in range(qty):
+            pos_order = self.PosOrder.create({
+                'company_id': self.company_id,
+                'session_id': self.pos_config.current_session_id.id,
+                'pricelist_id': self.partner1.property_product_pricelist.id,
+                'partner_id': self.partner1.id,
+                'lines': [(0, 0, {
+                    'name': "OL/0001",
+                    'product_id': product.id,
+                    'price_unit': untax + atax,
+                    'discount': 0.0,
+                    'qty': 1.0,
+                    'tax_ids': [(6, 0, product.taxes_id.ids)],
+                    'price_subtotal': untax,
+                    'price_subtotal_incl': untax + atax,
+                    'pack_lot_ids': [[0, 0, {'lot_name': lot.name}]],
+                })],
+                'amount_tax': atax,
+                'amount_total': untax + atax,
+                'amount_paid': 0,
+                'amount_return': 0,
+            })
+
+            context_make_payment = {
+                "active_ids": [pos_order.id],
+                "active_id": pos_order.id,
+            }
+            pos_make_payment = self.PosMakePayment.with_context(context_make_payment).create({
+                'amount': untax + atax,
+            })
+            context_payment = {'active_id': pos_order.id}
+            pos_make_payment.with_context(context_payment).check()
+
+            self.assertEqual(pos_order.state, 'paid')
+            self.assertEqual(pos_order.picking_id.move_line_ids.lot_id, lot)
+            self.assertEqual(pos_order.picking_id.move_line_ids.location_id, shelf1_location)
+
+        self.pos_config.current_session_id.action_pos_session_closing_control()
+
     def test_order_to_invoice(self):
 
         self.pos_config.open_session_cb()
