@@ -32,7 +32,7 @@ class PortalMixin(models.AbstractModel):
             self.sudo().write({'access_token': str(uuid.uuid4())})
         return self.access_token
 
-    def _get_share_url(self, redirect=False, signup_partner=False, pid=None):
+    def _get_share_url(self, redirect=False, signup_partner=False, pid=None, share_token=True):
         """
         Build the url of the record  that will be sent by mail and adds additional parameters such as
         access_token to bypass the recipient's rights,
@@ -50,7 +50,7 @@ class PortalMixin(models.AbstractModel):
             'model': self._name,
             'res_id': self.id,
         }
-        if hasattr(self, 'access_token'):
+        if share_token and hasattr(self, 'access_token'):
             params['access_token'] = self._portal_ensure_token()
         if pid:
             params['pid'] = pid
@@ -60,16 +60,16 @@ class PortalMixin(models.AbstractModel):
 
         return '%s?%s' % ('/mail/view' if redirect else self.access_url, url_encode(params))
 
-    def _notify_get_groups(self):
+    def _notify_get_groups(self, msg_vals=None):
         access_token = self._portal_ensure_token()
-        groups = super(PortalMixin, self)._notify_get_groups()
+        groups = super(PortalMixin, self)._notify_get_groups(msg_vals=msg_vals)
+        local_msg_vals = dict(msg_vals or {})
+
         if access_token and 'partner_id' in self._fields and self['partner_id']:
             customer = self['partner_id']
-            additional_params = {
-                'access_token': self.access_token,
-            }
-            additional_params.update(customer.signup_get_auth_param()[customer.id])
-            access_link = self._notify_get_action_link('view', **additional_params)
+            local_msg_vals['access_token'] = self.access_token
+            local_msg_vals.update(customer.signup_get_auth_param()[customer.id])
+            access_link = self._notify_get_action_link('view', **local_msg_vals)
 
             new_group = [
                 ('portal_customer', lambda pdata: pdata['id'] == customer.id, {
@@ -77,6 +77,7 @@ class PortalMixin(models.AbstractModel):
                     'button_access': {
                         'url': access_link,
                     },
+                    'notification_is_customer': True,
                 })
             ]
         else:
