@@ -5,13 +5,13 @@
 {
     'name': 'Point of Sale Discounts',
     'version': '1.0',
-    'category': 'Point of Sale',
+    'category': 'Sales/Point Of Sale',
     'sequence': 6,
     'summary': 'Simple Discounts in the Point of Sale ',
     'description': """
 
-This module allows the cashier to quickly give a percentage
-sale discount to a customer.
+This module allows the cashier to quickly give percentage-based
+discount to a customer.
 
 """,
     'depends': ['point_of_sale'],
@@ -23,4 +23,5 @@ sale discount to a customer.
         'static/src/xml/discount_templates.xml',
     ],
     'installable': True,
+    'license': 'LGPL-3',
 }
