@@ -4,7 +4,7 @@
 {
     'name': 'Point of Sale Receipt Reprinting',
     'version': '1.0',
-    'category': 'Point of Sale',
+    'category': 'Sales/Point Of Sale',
     'sequence': 6,
     'summary': 'Allow cashier to reprint receipts',
     'description': """
@@ -21,4 +21,5 @@ Allow cashier to reprint receipts
         'static/src/xml/reprint.xml',
     ],
     'installable': True,
+    'license': 'LGPL-3',
 }
