@@ -5,12 +5,12 @@
 {
     'name': 'Restaurant',
     'version': '1.0',
-    'category': 'Point of Sale',
+    'category': 'Sales/Point Of Sale',
     'sequence': 6,
     'summary': 'Restaurant extensions for the Point of Sale ',
     'description': """
 
-This module adds several restaurant features to the Point of Sale:
+This module adds several features to the Point of Sale that are specific to restaurant management:
 - Bill Printing: Allows you to print a receipt before the order is paid
 - Bill Splitting: Allows you to split an order into different orders
 - Kitchen Order Printing: allows you to print orders updates to kitchen or bar printers
@@ -37,4 +37,5 @@ This module adds several restaurant features to the Point of Sale:
     ],
     'installable': True,
     'auto_install': False,
+    'license': 'LGPL-3',
 }
