@@ -30,8 +30,8 @@ class PurchaseReport(models.Model):
     company_id = fields.Many2one('res.company', 'Company', readonly=True)
     currency_id = fields.Many2one('res.currency', 'Currency', readonly=True)
     user_id = fields.Many2one('res.users', 'Purchase Representative', readonly=True)
-    delay = fields.Float('Days to Confirm', digits=(16, 2), readonly=True)
-    delay_pass = fields.Float('Days to Receive', digits=(16, 2), readonly=True)
+    delay = fields.Float('Days to Confirm', digits=(16, 2), readonly=True, group_operator='avg')
+    delay_pass = fields.Float('Days to Receive', digits=(16, 2), readonly=True, group_operator='avg')
     price_total = fields.Float('Total', readonly=True)
     price_average = fields.Float('Average Cost', readonly=True, group_operator="avg")
     nbr_lines = fields.Integer('# of Lines', readonly=True)
