@@ -9,6 +9,20 @@ from datetime import datetime as dt, timedelta as td
 
 class TestReorderingRule(TransactionCase):
 
+    def setUp(self):
+        super(TestReorderingRule, self).setUp()
+        self.partner = self.env['res.partner'].create({
+            'name': 'Smith'
+        })
+
+        product_form = Form(self.env['product.product'])
+        product_form.name = 'Product A'
+        product_form.type = 'product'
+        with product_form.seller_ids.new() as seller:
+            seller.name = self.partner
+        product_form.route_ids.add(self.env.ref('purchase_stock.route_warehouse0_buy'))
+        self.product_01 = product_form.save()
+
     def test_reordering_rule(self):
         """
             - Receive products in 2 steps
@@ -18,19 +32,8 @@ class TestReorderingRule(TransactionCase):
         warehouse_1 = self.env['stock.warehouse'].search([('company_id', '=', self.env.user.id)], limit=1)
         warehouse_1.write({'reception_steps': 'two_steps'})
 
-        # Create a supplier
-        partner = self.env['res.partner'].create({
-            'name': 'Smith'
-        })
-
-        # create product and set the vendor
-        product_form = Form(self.env['product.product'])
-        product_form.name = 'Product A'
-        product_form.type = 'product'
-        with product_form.seller_ids.new() as seller:
-            seller.name = partner
-        product_form.route_ids.add(self.env.ref('purchase_stock.route_warehouse0_buy'))
-        product_01 = product_form.save()
+        partner = self.partner
+        product_01 = self.product_01
 
         # create reordering rule
         orderpoint_form = Form(self.env['stock.warehouse.orderpoint'])
@@ -143,3 +146,26 @@ class TestReorderingRule(TransactionCase):
             [("product_id", "=", product.id)])
         self.assertTrue(po_line)
         self.assertEqual(po_line.partner_id, secondary_vendor)
+
+    def test_change_pol_product(self):
+        """ In the PO generated by the scheduler, the user changes the product of the line. If the scheduler
+        is executed again, a new line should be added to the PO and correspond to the previous product """
+        product_form = Form(self.env['product.product'])
+        product_form.name = 'Product B'
+        product_form.type = 'product'
+        product_02 = product_form.save()
+
+        orderpoint_form = Form(self.env['stock.warehouse.orderpoint'])
+        orderpoint_form.product_id = self.product_01
+        orderpoint_form.product_min_qty = 10
+        orderpoint_form.product_max_qty = 50
+        order_point = orderpoint_form.save()
+
+        self.env['procurement.group'].run_scheduler()
+
+        purchase_order = self.env['purchase.order'].search([('partner_id', '=', self.partner.id)])
+        purchase_order.order_line.product_id = product_02
+
+        self.env['procurement.group'].run_scheduler()
+
+        self.assertEqual(purchase_order.order_line.mapped('product_id'), self.product_01 + product_02)
