@@ -45,5 +45,6 @@ This module contains all the common features of Sales Management and eCommerce.
         "static/src/xml/account_reconciliation.xml",
     ],
     'installable': True,
-    'auto_install': False
+    'auto_install': False,
+    'license': 'LGPL-3',
 }
