@@ -619,6 +619,182 @@ class TestSaleCouponProgramNumbers(TestSaleCouponCommon):
         order.recompute_coupon_lines()
         self.assertEqual(order.amount_total, 82.5, "The promotion programs should have been removed from the order to avoid negative amount")
 
+    def test_coupon_and_coupon_discount_fixed_amount_tax_excl(self):
+        """ Ensure multiple coupon can cohexists without making
+            the order go below 0
+            * Have an order of 300 (3 lines: 1 tax excl 15%, 2 notax)
+            * Apply a coupon A of 10% discount, unconditioned
+            * Apply a coupon B of 288.5 discount, unconditioned
+            * Order should not go below 0
+            * Even applying the coupon in reverse order should yield same result
+        """
+
+        coupon_program = self.env['sale.coupon.program'].create({
+            'name': '$288.5 coupon',
+            'program_type': 'coupon_program',
+            'reward_type': 'discount',
+            'discount_type': 'fixed_amount',
+            'discount_fixed_amount': 288.5,
+            'active': True,
+            'discount_apply_on': 'on_order',
+        })
+
+        order = self.empty_order
+        orderline = self.env['sale.order.line'].create([
+        {
+            'product_id': self.conferenceChair.id,
+            'name': 'Conference Chair',
+            'product_uom_qty': 1.0,
+            'price_unit': 100.0,
+            'order_id': order.id,
+            'tax_id': [(6, 0, (self.tax_15pc_excl.id,))],
+        },
+        {
+            'product_id': self.pedalBin.id,
+            'name': 'Computer Case',
+            'product_uom_qty': 1.0,
+            'price_unit': 100.0,
+            'order_id': order.id,
+            'tax_id': [(6, 0, [])],
+        },
+        {
+            'product_id': self.product_A.id,
+            'name': 'Computer Case',
+            'product_uom_qty': 1.0,
+            'price_unit': 100.0,
+            'order_id': order.id,
+            'tax_id': [(6, 0, [])],
+        },
+        ])
+
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+                'coupon_code': 'test_10pc'
+            }).process_coupon()
+        self.assertEqual(order.amount_total, 283.5, "The promotion program should be correctly applied")
+
+        self.env['sale.coupon.generate'].with_context(active_id=coupon_program.id).create({
+            'generation_type': 'nbr_coupon',
+            'nbr_coupons': 1,
+        }).generate_coupon()
+        coupon = coupon_program.coupon_ids
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+            'coupon_code': coupon.code
+        }).process_coupon()
+        order.recompute_coupon_lines()
+        #TODO fix numbers
+        # Need an in-depth inspection on the behavior with
+        # - multiple product with different VAT +
+        # - a fixed amount (greater than remaining amount to pay) +
+        # - discount amount
+        # And user should be able to swap the promotion order with a meaningful result.
+        self.assertEqual(order.amount_tax, 13.5)
+        self.assertEqual(order.amount_untaxed, 0.0, "The untaxed amount should not go below 0")
+        self.assertEqual(order.amount_total, 13.5, "The promotion program should not make the order total go below 0")
+
+        order.order_line[3:].unlink() #remove all coupon
+
+        order.recompute_coupon_lines()
+        self.assertEqual(len(order.order_line), 3, "The promotion program should be removed")
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+            'coupon_code': coupon.code
+        }).process_coupon()
+        self.assertEqual(order.amount_total, 26.5, "The promotion program should be correctly applied")
+        order.recompute_coupon_lines()
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+                'coupon_code': 'test_10pc'
+            }).process_coupon()
+        order.recompute_coupon_lines()
+        #TODO fix numbers
+        self.assertEqual(order.amount_tax, 13.5)
+        self.assertEqual(order.amount_untaxed, 0.0)
+        self.assertEqual(order.amount_total, 13.5, "The promotion program should not make the order total go below 0be altered after recomputation")
+
+    def test_coupon_and_coupon_discount_fixed_amount_tax_incl(self):
+        """ Ensure multiple coupon can cohexists without making
+            the order go below 0
+            * Have an order of 300 (3 lines: 1 tax incl 10%, 2 notax)
+            * Apply a coupon A of 10% discount, unconditioned
+            * Apply a coupon B of 290 discount, unconditioned
+            * Order should not go below 0
+            * Even applying the coupon in reverse order should yield same result
+        """
+
+        coupon_program = self.env['sale.coupon.program'].create({
+            'name': '$290 coupon',
+            'program_type': 'coupon_program',
+            'reward_type': 'discount',
+            'discount_type': 'fixed_amount',
+            'discount_fixed_amount': 290,
+            'active': True,
+            'discount_apply_on': 'on_order',
+        })
+
+        order = self.empty_order
+        orderline = self.env['sale.order.line'].create([
+        {
+            'product_id': self.conferenceChair.id,
+            'name': 'Conference Chair',
+            'product_uom_qty': 1.0,
+            'price_unit': 100.0,
+            'order_id': order.id,
+            'tax_id': [(6, 0, (self.tax_10pc_incl.id,))],
+        },
+        {
+            'product_id': self.pedalBin.id,
+            'name': 'Computer Case',
+            'product_uom_qty': 1.0,
+            'price_unit': 100.0,
+            'order_id': order.id,
+            'tax_id': [(6, 0, [])],
+        },
+        {
+            'product_id': self.product_A.id,
+            'name': 'Computer Case',
+            'product_uom_qty': 1.0,
+            'price_unit': 100.0,
+            'order_id': order.id,
+            'tax_id': [(6, 0, [])],
+        },
+        ])
+
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+                'coupon_code': 'test_10pc'
+            }).process_coupon()
+        self.assertEqual(order.amount_total, 270.0, "The promotion program should be correctly applied")
+
+        self.env['sale.coupon.generate'].with_context(active_id=coupon_program.id).create({
+            'generation_type': 'nbr_coupon',
+            'nbr_coupons': 1,
+        }).generate_coupon()
+        coupon = coupon_program.coupon_ids
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+            'coupon_code': coupon.code
+        }).process_coupon()
+        self.assertEqual(order.amount_total, 0.0, "The promotion program should not make the order total go below 0")
+        order.recompute_coupon_lines()
+        #TODO fix numbers
+        self.assertEqual(order.amount_total, 9.09, "The promotion program should not be altered after recomputation")
+        self.assertEqual(order.amount_tax, 8.18)
+        self.assertEqual(order.amount_untaxed, 0.91)
+
+        order.order_line[3:].unlink() #remove all coupon
+
+        order.recompute_coupon_lines()
+        self.assertEqual(len(order.order_line), 3, "The promotion program should be removed")
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+            'coupon_code': coupon.code
+        }).process_coupon()
+        self.assertEqual(order.amount_total, 10.0, "The promotion program should be correctly applied")
+        order.recompute_coupon_lines()
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+                'coupon_code': 'test_10pc'
+            }).process_coupon()
+        order.recompute_coupon_lines()
+        #TODO fix numbers
+        self.assertEqual(order.amount_tax, 9.01)
+        self.assertEqual(order.amount_untaxed, 0.08)
+        self.assertEqual(order.amount_total, 9.09, "The promotion program should not be altered after recomputation")
+
     def test_program_discount_on_multiple_specific_products(self):
         """ Ensure a discount on multiple specific products is correctly computed.
             - Simple: Discount must be applied on all the products set on the promotion
@@ -822,3 +998,184 @@ class TestSaleCouponProgramNumbers(TestSaleCouponCommon):
         order.recompute_coupon_lines()
         self.assertEqual(order.amount_total, 1486.80, "Discount improperly applied")
         self.assertEqual(len(order.order_line.ids), 2, "No discount applied while it should")
+
+    def test_program_free_prods_with_min_qty_and_reward_qty_and_rule(self):
+        order = self.empty_order
+        coupon_program = self.env['sale.coupon.program'].create({
+            'name': '2 free conference chair if at least 1 large cabinet',
+            'promo_code_usage': 'code_needed',
+            'program_type': 'promotion_program',
+            'reward_type': 'product',
+            'reward_product_quantity': 2,
+            'reward_product_id': self.conferenceChair.id,
+            'rule_min_quantity': 1,
+            'rule_products_domain': '["&", ["sale_ok","=",True], ["name","ilike","large cabinet"]]',
+        })
+        # set large cabinet and conference chair prices
+        self.largeCabinet.write({'list_price': 500, 'sale_ok': True,})
+        self.conferenceChair.write({'list_price': 100, 'sale_ok': True})
+
+        # create SOL
+        sol1 = self.env['sale.order.line'].create({
+            'product_id': self.largeCabinet.id,
+            'name': 'Large Cabinet',
+            'product_uom_qty': 1.0,
+            'order_id': order.id,
+        })
+        sol2 = self.env['sale.order.line'].create({
+            'product_id': self.conferenceChair.id,
+            'name': 'Conference chair',
+            'product_uom_qty': 2.0,
+            'order_id': order.id,
+        })
+
+        self.assertEqual(len(order.order_line), 2, 'The order must contain 2 order lines since the coupon is not yet applied')
+        self.assertEqual(order.amount_total, 700.0, 'The price must be 500.0 since the coupon is not yet applied')
+
+        # generate and apply coupon
+        self.env['sale.coupon.generate'].with_context(active_id=coupon_program.id).create({
+            'generation_type': 'nbr_coupon',
+            'nbr_coupons': 1,
+        }).generate_coupon()
+        coupon = coupon_program.coupon_ids
+        self.env['sale.coupon.apply.code'].with_context(active_id=order.id).create({
+            'coupon_code': coupon.code
+        }).process_coupon()
+
+        # Name                  | Qty | price_unit |  Tax     |  HTVA   |   TVAC  |  TVA  |
+        # --------------------------------------------------------------------------------
+        # Conference Chair      |  2  |    100.00  | /        |  200.00 |  200.00 |       /
+        # Large Cabinet         |  1  |    500.00  | /        |  500.00 |  500.00 |       /
+        #
+        # Free Conference Chair |  2  |   -100.00  | /        | -200.00 | -200.00 |       /
+        # --------------------------------------------------------------------------------
+        # TOTAL                                               |  500.00 |  500.00 |       /
+
+        self.assertEqual(len(order.order_line), 3, 'The order must contain 3 order lines including one for free conference chair')
+        self.assertEqual(order.amount_total, 500.0, 'The price must be 500.0 since two conference chairs are free')
+        self.assertEqual(order.order_line[2].price_total, -200.0, 'The last order line should apply a reduction of 200.0 since there are two conference chairs that cost 100.0 each')
+
+        # prevent user to get illicite discount by decreasing the to 1 the reward product qty after applying the coupon
+        sol2.product_uom_qty = 1.0
+        order.recompute_coupon_lines()
+
+        # in this case user should not have -200.0
+        # Name                  | Qty | price_unit |  Tax     |  HTVA   |   TVAC  |  TVA  |
+        # --------------------------------------------------------------------------------
+        # Conference Chair      |  1  |    100.00  | /        |  100.00 |  100.00 |       /
+        # Large Cabine          |  1  |    500.00  | /        |  500.00 |  500.00 |       /
+        #
+        # Free Conference Chair |  2  |   -100.00  | /        | -200.00 | -200.00 |       /
+        # --------------------------------------------------------------------------------
+        # TOTAL                                               |  400.00 |  400.00 |       /
+
+
+        # he should rather have this one
+        # Name                  | Qty | price_unit |  Tax     |  HTVA   |   TVAC  |  TVA  |
+        # --------------------------------------------------------------------------------
+        # Conference Chair      |  1  |    100.00  | /        |  100.00 |  100.00 |       /
+        # Large Cabinet         |  1  |    500.00  | /        |  500.00 |  500.00 |       /
+        #
+        # Free Conference Chair |  1  |   -100.00  | /        | -100.00 | -100.00 |       /
+        # --------------------------------------------------------------------------------
+        # TOTAL                                               |  500.00 |  500.00 |       /
+
+        self.assertEqual(order.amount_total, 500.0, 'The price must be 500.0 since two conference chairs are free and the user only bought one')
+        self.assertEqual(order.order_line[2].price_total, -100.0, 'The last order line should apply a reduction of 100.0 since there is one conference chair that cost 100.0')
+
+    def test_program_free_product_different_than_rule_product_with_multiple_application(self):
+        order = self.empty_order
+
+        self.env['sale.order.line'].create({
+            'product_id': self.drawerBlack.id,
+            'product_uom_qty': 2.0,
+            'order_id': order.id,
+        })
+        sol_B = self.env['sale.order.line'].create({
+            'product_id': self.largeMeetingTable.id,
+            'product_uom_qty': 1.0,
+            'order_id': order.id,
+        })
+
+        order.recompute_coupon_lines()
+
+        self.assertEqual(len(order.order_line), 3, 'The order must contain 3 order lines: 1x for Black Drawer, 1x for Large Meeting Table and 1x for free Large Meeting Table')
+        self.assertEqual(order.amount_total, self.drawerBlack.list_price * 2, 'The price must be 50.0 since the Large Meeting Table is free: 2*25.00 (Black Drawer) + 1*40000.00 (Large Meeting Table) - 1*40000.00 (free Large Meeting Table)')
+        self.assertEqual(order.order_line.filtered(lambda x: x.is_reward_line).product_uom_qty, 1, "Only one free Large Meeting Table should be offered, as only one paid Large Meeting Table is in cart. You can't have more free product than paid product.")
+
+        sol_B.product_uom_qty = 2
+
+        order.recompute_coupon_lines()
+
+        self.assertEqual(len(order.order_line), 3, 'The order must contain 3 order lines: 1x for Black Drawer, 1x for Large Meeting Table and 1x for free Large Meeting Table')
+        self.assertEqual(order.amount_total, self.drawerBlack.list_price * 2, 'The price must be 50.0 since the 2 Large Meeting Table are free: 2*25.00 (Black Drawer) + 2*40000.00 (Large Meeting Table) - 2*40000.00 (free Large Meeting Table)')
+        self.assertEqual(order.order_line.filtered(lambda x: x.is_reward_line).product_uom_qty, 2, 'The 2 Large Meeting Table should be offered, as the promotion says 1 Black Drawer = 1 free Large Meeting Table and there are 2 Black Drawer')
+
+    def test_program_modify_reward_line_qty(self):
+        order = self.empty_order
+        product_F = self.env['product.product'].create({
+            'name': 'Product F',
+            'list_price': 100,
+            'sale_ok': True,
+            'taxes_id': [(6, 0, [])],
+        })
+        self.env['sale.coupon.program'].create({
+            'name': '1 Product F = 5$ discount',
+            'promo_code_usage': 'no_code_needed',
+            'reward_type': 'discount',
+            'discount_type': 'fixed_amount',
+            'discount_fixed_amount': 5,
+            'rule_products_domain': "[('id', 'in', [%s])]" % (product_F.id),
+            'active': True,
+        })
+
+        self.env['sale.order.line'].create({
+            'product_id': product_F.id,
+            'product_uom_qty': 2.0,
+            'order_id': order.id,
+        })
+
+        order.recompute_coupon_lines()
+
+        self.assertEqual(len(order.order_line), 2, 'The order must contain 2 order lines: 1x Product F and 1x 5$ discount')
+        self.assertEqual(order.amount_total, 195.0, 'The price must be 195.0 since there is a 5$ discount and 2x Product F')
+        self.assertEqual(order.order_line.filtered(lambda x: x.is_reward_line).product_uom_qty, 1, 'The reward line should have a quantity of 1 since Fixed Amount discounts apply only once per Sale Order')
+
+        order.order_line[1].product_uom_qty = 2
+
+        self.assertEqual(len(order.order_line), 2, 'The order must contain 2 order lines: 1x Product F and 1x 5$ discount')
+        self.assertEqual(order.amount_total, 190.0, 'The price must be 190.0 since there is now 2x 5$ discount and 2x Product F')
+        self.assertEqual(order.order_line.filtered(lambda x: x.is_reward_line).price_unit, -5, 'The discount unit price should still be -5 after the quantity was manually changed')
+
+    def test_program_maximum_use_number_with_other_promo(self):
+        self.env['sale.coupon.program'].create({
+            'name': '20% discount on first order',
+            'promo_code_usage': 'no_code_needed',
+            'program_type': 'promotion_program',
+            'discount_type': 'percentage',
+            'discount_percentage': 20.0,
+            'maximum_use_number': 1,
+        })
+        self.p1.promo_code_usage = 'no_code_needed'
+
+        #check that 20% is applied at first order
+        order = self.empty_order
+        self.env['sale.order.line'].create({
+            'product_id': self.drawerBlack.id,
+            'product_uom_qty': 1.0,
+            'order_id': order.id,
+        })
+        order.recompute_coupon_lines()
+        self.assertEqual(order.amount_total, 20.0, "20% discount should be applied")
+        self.assertEqual(len(order.order_line.ids), 2, "discount should be applied")
+
+        #check that 10% is applied at second order
+        order2 = self.env['sale.order'].create({'partner_id': self.steve.id})
+        self.env['sale.order.line'].create({
+            'product_id': self.drawerBlack.id,
+            'product_uom_qty': 1.0,
+            'order_id': order2.id,
+        })
+        order2.recompute_coupon_lines()
+        self.assertEqual(order2.amount_total, 22.5, "10% discount should be applied")
+        self.assertEqual(len(order2.order_line.ids), 2, "discount should be applied")
