@@ -30,7 +30,7 @@ class PurchaseOrder(models.Model):
                 views_or_xmlid='sale_purchase.exception_sale_on_purchase_cancellation',
                 render_context={
                     'purchase_orders': purchase_order_lines.mapped('order_id'),
-                    'purchase_lines': purchase_order_lines,
+                    'purchase_order_lines': purchase_order_lines,
             })
 
 
