@@ -553,6 +553,67 @@ class TestAngloSaxonValuation(SavepointCase):
         self.assertEqual(income_aml.debit, 0)
         self.assertEqual(income_aml.credit, 24)
 
+    def test_avco_ordered_return_and_receipt(self):
+        """ Sell and deliver some products before the user encodes the products receipt """
+        product = self.product
+        product.invoice_policy = 'order'
+        product.type = 'product'
+        product.categ_id.property_cost_method = 'average'
+        product.categ_id.property_valuation = 'real_time'
+        product.list_price = 100
+        product.standard_price = 50
+
+        so = self.env['sale.order'].create({
+            'partner_id': self.customer.id,
+            'partner_invoice_id': self.customer.id,
+            'partner_shipping_id': self.customer.id,
+            'order_line': [(0, 0, {
+                'name': product.name,
+                'product_id': product.id,
+                'product_uom_qty': 5.0,
+                'product_uom': product.uom_id.id,
+                'price_unit': product.list_price})],
+        })
+        so.action_confirm()
+
+        pick = so.picking_ids
+        pick.move_lines.write({'quantity_done': 5})
+        pick.button_validate()
+
+        product.standard_price = 40
+
+        stock_return_picking_form = Form(self.env['stock.return.picking']
+            .with_context(active_ids=pick.ids, active_id=pick.sorted().ids[0], active_model='stock.picking'))
+        return_wiz = stock_return_picking_form.save()
+        return_wiz.product_return_moves.quantity = 1
+        return_wiz.product_return_moves.to_refund = False
+        res = return_wiz.create_returns()
+
+        return_pick = self.env['stock.picking'].browse(res['res_id'])
+        return_pick.move_lines.write({'quantity_done': 1})
+        return_pick.button_validate()
+
+        picking = self.env['stock.picking'].create({
+            'location_id': self.env.ref('stock.stock_location_suppliers').id,
+            'location_dest_id': self.stock_location.id,
+            'picking_type_id': self.env['stock.warehouse'].search([], limit=1).in_type_id.id,
+        })
+        # We don't set the price_unit so that the `standard_price` will be used (see _get_price_unit()):
+        self.env['stock.move'].create({
+            'name': 'test_immediate_validate_1',
+            'location_id': self.env.ref('stock.stock_location_suppliers').id,
+            'location_dest_id': self.stock_location.id,
+            'picking_id': picking.id,
+            'product_id': product.id,
+            'product_uom': product.uom_id.id,
+            'quantity_done': 1,
+        })
+        picking.button_validate()
+
+        invoice = so._create_invoices()
+        invoice.action_post()
+        self.assertEqual(invoice.state, 'posted')
+
     # -------------------------------------------------------------------------
     # AVCO Delivered
     # -------------------------------------------------------------------------
@@ -1008,3 +1069,122 @@ class TestAngloSaxonValuation(SavepointCase):
         cogs_aml = amls.filtered(lambda aml: aml.account_id == self.expense_account)
         self.assertEqual(cogs_aml.debit, 56)
         self.assertEqual(cogs_aml.credit, 0)
+
+    def test_fifo_delivered_invoice_post_delivery_with_return(self):
+        """Receive 2@10. SO1 2@12. Return 1 from SO1. SO2 1@12. Receive 1@20.
+        Re-deliver returned from SO1. Invoice after delivering everything."""
+        self.product.categ_id.property_cost_method = 'fifo'
+        self.product.invoice_policy = 'delivery'
+
+        # Receive 2@10.
+        in_move_1 = self.env['stock.move'].create({
+            'name': 'a',
+            'product_id': self.product.id,
+            'location_id': self.env.ref('stock.stock_location_suppliers').id,
+            'location_dest_id': self.stock_location.id,
+            'product_uom': self.product.uom_id.id,
+            'product_uom_qty': 2,
+            'price_unit': 10,
+        })
+        in_move_1._action_confirm()
+        in_move_1.quantity_done = 2
+        in_move_1._action_done()
+
+        # Create, confirm and deliver a sale order for 2@12 (SO1)
+        so_1 = self._so_and_confirm_two_units()
+        so_1.picking_ids.move_lines.quantity_done = 2
+        so_1.picking_ids.button_validate()
+
+        # Return 1 from SO1
+        stock_return_picking_form = Form(
+            self.env['stock.return.picking'].with_context(
+                active_ids=so_1.picking_ids.ids, active_id=so_1.picking_ids.ids[0], active_model='stock.picking')
+        )
+        stock_return_picking = stock_return_picking_form.save()
+        stock_return_picking.product_return_moves.quantity = 1.0
+        stock_return_picking_action = stock_return_picking.create_returns()
+        return_pick = self.env['stock.picking'].browse(stock_return_picking_action['res_id'])
+        return_pick.action_assign()
+        return_pick.move_lines.quantity_done = 1
+        return_pick.action_done()
+
+        # Create, confirm and deliver a sale order for 1@12 (SO2)
+        so_2 = self.env['sale.order'].create({
+            'partner_id': self.customer.id,
+            'order_line': [
+                (0, 0, {
+                    'name': self.product.name,
+                    'product_id': self.product.id,
+                    'product_uom_qty': 1.0,
+                    'product_uom': self.product.uom_id.id,
+                    'price_unit': 12,
+                    'tax_id': False,  # no love taxes amls
+                })],
+        })
+        so_2.action_confirm()
+        so_2.picking_ids.move_lines.quantity_done = 1
+        so_2.picking_ids.button_validate()
+
+        # Receive 1@20
+        in_move_2 = self.env['stock.move'].create({
+            'name': 'a',
+            'product_id': self.product.id,
+            'location_id': self.env.ref('stock.stock_location_suppliers').id,
+            'location_dest_id': self.stock_location.id,
+            'product_uom': self.product.uom_id.id,
+            'product_uom_qty': 1,
+            'price_unit': 20,
+        })
+        in_move_2._action_confirm()
+        in_move_2.quantity_done = 1
+        in_move_2._action_done()
+
+        # Re-deliver returned 1 from SO1
+        stock_redeliver_picking_form = Form(
+            self.env['stock.return.picking'].with_context(
+                active_ids=return_pick.ids, active_id=return_pick.ids[0], active_model='stock.picking')
+        )
+        stock_redeliver_picking = stock_redeliver_picking_form.save()
+        stock_redeliver_picking.product_return_moves.quantity = 1.0
+        stock_redeliver_picking_action = stock_redeliver_picking.create_returns()
+        redeliver_pick = self.env['stock.picking'].browse(stock_redeliver_picking_action['res_id'])
+        redeliver_pick.action_assign()
+        redeliver_pick.move_lines.quantity_done = 1
+        redeliver_pick.action_done()
+
+        # Invoice the sale orders
+        invoice_1 = so_1.with_context(default_journal_id=self.journal_sale.id)._create_invoices()
+        invoice_1.post()
+        invoice_2 = so_2.with_context(default_journal_id=self.journal_sale.id)._create_invoices()
+        invoice_2.post()
+
+        # Check the resulting accounting entries
+        amls_1 = invoice_1.line_ids
+        self.assertEqual(len(amls_1), 4)
+        stock_out_aml_1 = amls_1.filtered(lambda aml: aml.account_id == self.stock_output_account)
+        self.assertEqual(stock_out_aml_1.debit, 0)
+        self.assertEqual(stock_out_aml_1.credit, 30)
+        cogs_aml_1 = amls_1.filtered(lambda aml: aml.account_id == self.expense_account)
+        self.assertEqual(cogs_aml_1.debit, 30)
+        self.assertEqual(cogs_aml_1.credit, 0)
+        receivable_aml_1 = amls_1.filtered(lambda aml: aml.account_id == self.recv_account)
+        self.assertEqual(receivable_aml_1.debit, 24)
+        self.assertEqual(receivable_aml_1.credit, 0)
+        income_aml_1 = amls_1.filtered(lambda aml: aml.account_id == self.income_account)
+        self.assertEqual(income_aml_1.debit, 0)
+        self.assertEqual(income_aml_1.credit, 24)
+
+        amls_2 = invoice_2.line_ids
+        self.assertEqual(len(amls_2), 4)
+        stock_out_aml_2 = amls_2.filtered(lambda aml: aml.account_id == self.stock_output_account)
+        self.assertEqual(stock_out_aml_2.debit, 0)
+        self.assertEqual(stock_out_aml_2.credit, 10)
+        cogs_aml_2 = amls_2.filtered(lambda aml: aml.account_id == self.expense_account)
+        self.assertEqual(cogs_aml_2.debit, 10)
+        self.assertEqual(cogs_aml_2.credit, 0)
+        receivable_aml_2 = amls_2.filtered(lambda aml: aml.account_id == self.recv_account)
+        self.assertEqual(receivable_aml_2.debit, 12)
+        self.assertEqual(receivable_aml_2.credit, 0)
+        income_aml_2 = amls_2.filtered(lambda aml: aml.account_id == self.income_account)
+        self.assertEqual(income_aml_2.debit, 0)
+        self.assertEqual(income_aml_2.credit, 12)
