@@ -62,14 +62,14 @@ class TestPingenSend(AccountingTestCase):
         }
 
         response = requests.post(self.pingen_url, data=self.data, files=files)
-        if 400 <= response.status_code <= 599:
+        if 400 <= response.status_code <= 599 or response.json()['error']:
             msg = "%(code)s %(side)s Error: %(reason)s for url: %(url)s\n%(body)s" % {
                 'code': response.status_code,
                 'side': r"%s",
                 'reason': response.reason,
                 'url': self.pingen_url,
                 'body': response.text}
-            if response.status_code <= 499:
+            if response.status_code <= 499 or response.json()['error']:
                 raise requests.HTTPError(msg % "Client")
             else:
                 _logger.warning(msg % "Server")
