@@ -130,7 +130,7 @@ class Company(models.Model):
     def create_missing_inventory_loss_location(self):
         company_ids  = self.env['res.company'].search([])
         inventory_loss_product_template_field = self.env['ir.model.fields'].search([('model','=','product.template'),('name','=','property_stock_inventory')])
-        companies_having_property = self.env['ir.property'].search([('fields_id', '=', inventory_loss_product_template_field.id)]).mapped('company_id')
+        companies_having_property = self.env['ir.property'].search([('fields_id', '=', inventory_loss_product_template_field.id),('res_id','=',False)]).mapped('company_id')
         company_without_property = company_ids - companies_having_property
         for company in company_without_property:
             company._create_inventory_loss_location()
@@ -139,7 +139,7 @@ class Company(models.Model):
     def create_missing_production_location(self):
         company_ids  = self.env['res.company'].search([])
         production_product_template_field = self.env['ir.model.fields'].search([('model','=','product.template'),('name','=','property_stock_production')])
-        companies_having_property = self.env['ir.property'].search([('fields_id', '=', production_product_template_field.id)]).mapped('company_id')
+        companies_having_property = self.env['ir.property'].search([('fields_id', '=', production_product_template_field.id),('res_id','=',False)]).mapped('company_id')
         company_without_property = company_ids - companies_having_property
         for company in company_without_property:
             company._create_production_location()
