@@ -797,3 +797,94 @@ class TestPacking(SavepointCase):
         with Form(picking) as picking_form:
             picking_form.package_level_ids.remove(0)
         self.assertEqual(len(picking.move_lines), 1, 'Should have only 1 stock move')
+
+    def test_picking_state_with_null_qty(self):
+        receipt_form = Form(self.env['stock.picking'].with_context(default_immediate_transfer=False))
+        picking_type_id = self.warehouse.out_type_id
+        receipt_form.picking_type_id = picking_type_id
+        with receipt_form.move_ids_without_package.new() as move_line:
+            move_line.product_id = self.productA
+            move_line.product_uom_qty = 10
+        with receipt_form.move_ids_without_package.new() as move_line:
+            move_line.product_id = self.productB
+            move_line.product_uom_qty = 10
+        receipt = receipt_form.save()
+        receipt.action_confirm()
+        self.assertEqual(receipt.state, 'confirmed')
+        receipt.move_ids_without_package[1].product_uom_qty = 0
+        self.assertEqual(receipt.state, 'confirmed')
+
+        receipt_form = Form(self.env['stock.picking'].with_context(default_immediate_transfer=True))
+        picking_type_id = self.warehouse.out_type_id
+        receipt_form.picking_type_id = picking_type_id
+        with receipt_form.move_ids_without_package.new() as move_line:
+            move_line.product_id = self.productA
+            move_line.quantity_done = 10
+        with receipt_form.move_ids_without_package.new() as move_line:
+            move_line.product_id = self.productB
+            move_line.quantity_done = 10
+        receipt = receipt_form.save()
+        receipt.action_confirm()
+        self.assertEqual(receipt.state, 'assigned')
+        receipt.move_ids_without_package[1].product_uom_qty = 0
+        self.assertEqual(receipt.state, 'assigned')
+
+    def test_2_steps_and_backorder(self):
+        """ When creating a backorder with a package, the latter should be reserved in the new picking. Moreover,
+         the initial picking shouldn't have any line about this package """
+        def create_picking(type, from_loc, to_loc):
+            picking = self.env['stock.picking'].create({
+                'picking_type_id': type.id,
+                'location_id': from_loc.id,
+                'location_dest_id': to_loc.id,
+            })
+            move_A, move_B = self.env['stock.move'].create([{
+                'name': self.productA.name,
+                'product_id': self.productA.id,
+                'product_uom_qty': 1,
+                'product_uom': self.productA.uom_id.id,
+                'picking_id': picking.id,
+                'location_id': from_loc.id,
+                'location_dest_id': to_loc.id,
+            }, {
+                'name': self.productB.name,
+                'product_id': self.productB.id,
+                'product_uom_qty': 1,
+                'product_uom': self.productB.uom_id.id,
+                'picking_id': picking.id,
+                'location_id': from_loc.id,
+                'location_dest_id': to_loc.id,
+            }])
+            picking.action_confirm()
+            picking.action_assign()
+            return picking, move_A, move_B
+
+        self.warehouse.delivery_steps = 'pick_ship'
+
+        output_location = self.warehouse.wh_output_stock_loc_id
+        pick_type = self.warehouse.pick_type_id
+        delivery_type = self.warehouse.out_type_id
+
+        self.env['stock.quant']._update_available_quantity(self.productA, self.stock_location, 1)
+        self.env['stock.quant']._update_available_quantity(self.productB, self.stock_location, 1)
+
+        picking, moveA, moveB = create_picking(pick_type, pick_type.default_location_src_id, pick_type.default_location_dest_id)
+        moveA.move_line_ids.qty_done = 1
+        picking.put_in_pack()
+        moveB.move_line_ids.qty_done = 1
+        picking.put_in_pack()
+        picking.button_validate()
+
+        picking, _, _ = create_picking(delivery_type, delivery_type.default_location_src_id, self.customer_location)
+        packA, packB = picking.package_level_ids
+        with Form(picking) as picking_form:
+            with picking_form.package_level_ids_details.edit(0) as package_level:
+                package_level.is_done = True
+        action_data = picking.button_validate()
+        backorder_wizard = self.env[action_data['res_model']].browse(action_data['res_id'])
+        backorder_wizard.process()
+        bo = self.env['stock.picking'].search([('backorder_id', '=', picking.id)])
+
+        self.assertNotIn(packB, picking.package_level_ids)
+        self.assertEqual(packB, bo.package_level_ids)
+        self.assertEqual(bo.package_level_ids.state, 'assigned')
