@@ -3,8 +3,8 @@ odoo.define('survey.survey', function (require) {
 
 require('web.dom_ready');
 var core = require('web.core');
+var session = require('web.session');
 var time = require('web.time');
-var ajax = require('web.ajax');
 var field_utils = require('web.field_utils');
 var Dialog = require('web.Dialog');
 
@@ -183,15 +183,10 @@ if(!the_form.length) {
         }
     });
 
-    function load_locale(){
-        var url = "/web/webclient/locale/" + (document.documentElement.getAttribute('lang') || 'en_US').replace('-', '_');
-        return ajax.loadJS(url);
-    }
-
     // datetimepicker use moment locale to display date format according to language
     // frontend does not load moment locale at all.
     // so wait until DOM ready with locale then init datetimepicker
-    load_locale().then(function(){
+    session.load_translations().then(function(){
         _.each($('.input-group.date'), function(date_field){
             var disabledDates = [];
             var minDate, maxDate;
