@@ -10,8 +10,10 @@ from . import test_mail_mail
 from . import test_mail_channel
 from . import test_mail_channel_partner
 from . import test_mail_gateway
+from . import test_mail_multicompany
 from . import test_mail_redirect
 from . import test_mail_template
+from . import test_mail_tools
 from . import test_message_composer
 from . import test_message_management
 from . import test_message_post
