@@ -1491,7 +1491,8 @@ var PartialEvaluator = (function PartialEvaluatorClosure() {
 
     getBaseFontMetrics: function PartialEvaluator_getBaseFontMetrics(name) {
       var defaultWidth = 0;
-      var widths = [];
+      // Odoo: backport mozilla/pdf.js@8805614a03c for courier font bug with chrome 92
+      var widths = Object.create(null);
       var monospace = false;
       var lookupName = (stdFontMap[name] || name);
 
