@@ -88,11 +88,11 @@ var FormController = BasicController.extend({
      *                            for the new record.
      * @returns {Promise}
      */
-    createRecord: function (parentID) {
+    createRecord: function (parentID, additionalContext) {
         var self = this;
         var record = this.model.get(this.handle, {raw: true});
         return this.model.load({
-            context: record.getContext(),
+            context: record.getContext({ additionalContext: additionalContext}),
             fields: record.fields,
             fieldsInfo: record.fieldsInfo,
             modelName: this.modelName,
@@ -574,7 +574,7 @@ var FormController = BasicController.extend({
         var attrs = ev.data.attrs;
         if (attrs.confirm) {
             def = new Promise(function (resolve, reject) {
-                Dialog.confirm(this, attrs.confirm, {
+                Dialog.confirm(self, attrs.confirm, {
                     confirm_callback: saveAndExecuteAction,
                 }).on("closed", null, resolve);
             });
