@@ -23,7 +23,9 @@ var RecordQuickCreate = Widget.extend({
         'click .o_kanban_add': '_onAddClicked',
         'click .o_kanban_edit': '_onEditClicked',
         'click .o_kanban_cancel': '_onCancelClicked',
+        'mousedown': '_onMouseDown',
     },
+    mouseDownInside: false,
 
     /**
      * @override
@@ -257,6 +259,9 @@ var RecordQuickCreate = Widget.extend({
      * @param {MouseEvent} ev
      */
     _onWindowClicked: function (ev) {
+        var mouseDownInside = this.mouseDownInside;
+
+        this.mouseDownInside = false;
         // ignore clicks if the quick create is not in the dom
         if (!document.contains(this.el)) {
             return;
@@ -290,12 +295,21 @@ var RecordQuickCreate = Widget.extend({
         }
 
         // ignore clicks if target is inside the quick create
-        if (this.el.contains(ev.target) || this.el === ev.target) {
+        if (this.el.contains(ev.target) || this.el === ev.target || mouseDownInside) {
             return;
         }
 
         this.cancel();
     },
+    /**
+     * Detects if the click is originally from the quick create
+     *
+     * @private
+     * @param {MouseEvent} ev
+     */
+    _onMouseDown: function(ev){
+        this.mouseDownInside = true;
+    }
 });
 
 return RecordQuickCreate;
