@@ -87,6 +87,9 @@ var FormViewDialog = ViewDialog.extend({
      *   well, and in that case, it will be used without loading anything.
      * @param {boolean} [options.shouldSaveLocally] if true, the view dialog
      *   will save locally instead of actually saving (useful for one2manys)
+     * @param {function} [options._createContext] function to get context for name field
+     *   useful for many2many_tags widget where we want to removed default_name field
+     *   context.
      */
     init: function (parent, options) {
         var self = this;
@@ -96,6 +99,7 @@ var FormViewDialog = ViewDialog.extend({
         this.on_saved = options.on_saved || (function () {});
         this.on_remove = options.on_remove || (function () {});
         this.context = options.context;
+        this._createContext = options._createContext;
         this.model = options.model;
         this.parentID = options.parentID;
         this.recordID = options.recordID;
@@ -137,7 +141,12 @@ var FormViewDialog = ViewDialog.extend({
                         classes: "btn-primary",
                         click: function () {
                             self._save()
-                                .then(self.form_view.createRecord.bind(self.form_view, self.parentID))
+                                .then(function () {
+                                    // reset default name field from context when Save & New is clicked, pass additional
+                                    // context so that when getContext is called additional context resets it
+                                    const additionalContext = self._createContext && self._createContext(false);
+                                    self.form_view.createRecord(self.parentID, additionalContext);
+                                })
                                 .then(function () {
                                     if (!self.deletable) {
                                         return;
@@ -200,6 +209,7 @@ var FormViewDialog = ViewDialog.extend({
                 model: self.model,
                 parentID: self.parentID,
                 recordID: self.recordID,
+                isFromFormViewDialog: true
             });
             return formview.getController(self);
         }).then(function (formView) {
