@@ -7,10 +7,9 @@ class ResConfigSettings(models.TransientModel):
     _inherit = 'res.config.settings'
 
     def _get_crm_default_team_domain(self):
-        if self.env.user.has_group('crm.group_use_lead'):
-            return [('use_leads', '=', True)]
-        else:
+        if not self.env.user.has_group('crm.group_use_lead'):
             return [('use_opportunities', '=', True)]
+        return [('use_leads', '=', True)]
 
     crm_default_team_id = fields.Many2one(
         'crm.team', string='Default Sales Team', related='website_id.crm_default_team_id', readonly=False,
