@@ -212,7 +212,7 @@ class Theme(models.AbstractModel):
 class IrUiView(models.Model):
     _inherit = 'ir.ui.view'
 
-    theme_template_id = fields.Many2one('theme.ir.ui.view')
+    theme_template_id = fields.Many2one('theme.ir.ui.view', copy=False)
 
     def write(self, vals):
         no_arch_updated_views = other_views = self.env['ir.ui.view']
@@ -232,17 +232,17 @@ class IrUiView(models.Model):
 class IrAttachment(models.Model):
     _inherit = 'ir.attachment'
 
-    key = fields.Char()
-    theme_template_id = fields.Many2one('theme.ir.attachment')
+    key = fields.Char(copy=False)
+    theme_template_id = fields.Many2one('theme.ir.attachment', copy=False)
 
 
 class WebsiteMenu(models.Model):
     _inherit = 'website.menu'
 
-    theme_template_id = fields.Many2one('theme.website.menu')
+    theme_template_id = fields.Many2one('theme.website.menu', copy=False)
 
 
 class WebsitePage(models.Model):
     _inherit = 'website.page'
 
-    theme_template_id = fields.Many2one('theme.website.page')
+    theme_template_id = fields.Many2one('theme.website.page', copy=False)
