@@ -142,7 +142,7 @@ def exec_pg_command_pipe(name, *args):
 #file_path_root = os.getcwd()
 #file_path_addons = os.path.join(file_path_root, 'addons')
 
-def file_open(name, mode="r", subdir='addons', pathinfo=False):
+def file_open(name, mode="r", subdir='addons', pathinfo=False, filter_ext=None):
     """Open a file from the OpenERP root, using a subdir folder.
 
     Example::
@@ -154,6 +154,7 @@ def file_open(name, mode="r", subdir='addons', pathinfo=False):
     @param mode file open mode
     @param subdir subdirectory
     @param pathinfo if True returns tuple (fileobject, filepath)
+    @param filter_ext: optional list of supported extensions (without leading dot)
 
     @return fileobject if pathinfo is False else (fileobject, filepath)
     """
@@ -176,7 +177,7 @@ def file_open(name, mode="r", subdir='addons', pathinfo=False):
         else:
             # It is outside the OpenERP root: skip zipfile lookup.
             base, name = os.path.split(name)
-        return _fileopen(name, mode=mode, basedir=base, pathinfo=pathinfo, basename=basename)
+        return _fileopen(name, mode=mode, basedir=base, pathinfo=pathinfo, basename=basename, filter_ext=filter_ext)
 
     if name.replace(os.sep, '/').startswith('addons/'):
         subdir = 'addons'
@@ -194,15 +195,15 @@ def file_open(name, mode="r", subdir='addons', pathinfo=False):
         for adp in adps:
             try:
                 return _fileopen(name2, mode=mode, basedir=adp,
-                                 pathinfo=pathinfo, basename=basename)
+                                 pathinfo=pathinfo, basename=basename, filter_ext=filter_ext)
             except IOError:
                 pass
 
     # Second, try to locate in root_path
-    return _fileopen(name, mode=mode, basedir=rtp, pathinfo=pathinfo, basename=basename)
+    return _fileopen(name, mode=mode, basedir=rtp, pathinfo=pathinfo, basename=basename, filter_ext=filter_ext)
 
 
-def _fileopen(path, mode, basedir, pathinfo, basename=None):
+def _fileopen(path, mode, basedir, pathinfo, basename=None, filter_ext=None):
     name = os.path.normpath(os.path.normcase(os.path.join(basedir, path)))
 
     import odoo.modules as addons
@@ -214,6 +215,9 @@ def _fileopen(path, mode, basedir, pathinfo, basename=None):
     else:
         raise ValueError("Unknown path: %s" % name)
 
+    if filter_ext and not name.lower().endswith(filter_ext):
+        raise ValueError("Unsupported path: %s" % name)
+
     if basename is None:
         basename = name
     # Give higher priority to module directories, which is
@@ -1165,7 +1169,6 @@ else:
     def html_escape(text):
         return werkzeug.utils.escape(text)
 
-
 def get_lang(env, lang_code=False):
     """
     Retrieve the first lang object installed, by checking the parameter lang_code,
@@ -1179,6 +1182,14 @@ def get_lang(env, lang_code=False):
         if code in langs:
             return env['res.lang']._lang_get(code)
 
+def babel_locale_parse(lang_code):
+    try:
+        return babel.Locale.parse(lang_code)
+    except:
+        try:
+            return babel.Locale.default()
+        except:
+            return babel.Locale.parse("en_US")
 
 def formatLang(env, value, digits=None, grouping=True, monetary=False, dp=False, currency_obj=False):
     """
@@ -1238,7 +1249,7 @@ def format_date(env, value, lang_code=False, date_format=False):
             value = odoo.fields.Datetime.from_string(value)
 
     lang = get_lang(env, lang_code)
-    locale = babel.Locale.parse(lang.code)
+    locale = babel_locale_parse(lang.code)
     if not date_format:
         date_format = posix_to_ldml(lang.date_format, locale=locale)
 
@@ -1257,7 +1268,7 @@ def parse_date(env, value, lang_code=False):
         :rtype: datetime.date
     '''
     lang = get_lang(env, lang_code)
-    locale = babel.Locale.parse(lang.code)
+    locale = babel_locale_parse(lang.code)
     try:
         return babel.dates.parse_date(value, locale=locale)
     except:
@@ -1289,7 +1300,7 @@ def format_datetime(env, value, tz=False, dt_format='medium', lang_code=False):
 
     lang = get_lang(env, lang_code)
 
-    locale = babel.Locale.parse(lang.code or lang_code)  # lang can be inactive, so `lang`is empty
+    locale = babel_locale_parse(lang.code or lang_code)  # lang can be inactive, so `lang`is empty
     if not dt_format:
         date_format = posix_to_ldml(lang.date_format, locale=locale)
         time_format = posix_to_ldml(lang.time_format, locale=locale)
@@ -1318,7 +1329,7 @@ def format_time(env, value, tz=False, time_format='medium', lang_code=False):
         return ''
 
     lang = get_lang(env, lang_code)
-    locale = babel.Locale.parse(lang.code)
+    locale = babel_locale_parse(lang.code)
     if not time_format:
         time_format = posix_to_ldml(lang.time_format, locale=locale)
 
@@ -1329,7 +1340,7 @@ def _format_time_ago(env, time_delta, lang_code=False, add_direction=True):
     if not lang_code:
         langs = [code for code, _ in env['res.lang'].get_installed()]
         lang_code = env.context['lang'] if env.context.get('lang') in langs else (env.user.company_id.partner_id.lang or langs[0])
-    locale = babel.Locale.parse(lang_code)
+    locale = babel_locale_parse(lang_code)
     return babel.dates.format_timedelta(-time_delta, add_direction=add_direction, locale=locale)
 
 
